#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue May 28 13:32:53 2019

@author: hogbobson
"""
import numpy as np

class timegen:
    def __init__(self):
        pass
    
    def time_seconds(self, seconds):
        return seconds

    def time_minutes(self, minutes):
        return self.time_seconds(60*minutes)
    
    def time_hours(self, hours):
        return self.time_minutes(60*hours)
    
    def time_days(self, days):
        return self.time_hours(24*days)
    
    def time_months(self, months):
        return self.time_days(30*months)
    
    def time_years(self, years): #You cant top the elegance of pi*1e7!
        return np.pi * 1e7 * years
    
    def time_years_precise(self, years):
        return self.time_days(365.256363004*years)
    
    def time_Myr(self, mega_years):
        return self.time_years(1e6*mega_years)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue May 28 19:32:15 2019

@author: hogbobson
"""
import numpy as np
from numpy import linalg as LA
from astropy import constants as astcnst

class force:
    def __init__(self):
        pass
    
    def gravity(self,r,M):
        """ Compute gravitational acceleration at r,
        shamelessly copied from 7a in computational astrophysics. """
        rm = LA.norm(r,axis = 2)     # Find the magnitude of distances (usually SSO.d is loaded in here)
        rm[rm == 0] = np.nan    # Make 0s nan so we avoid divide by 0.
        rmcub = rm*rm*rm        # They say rm*rm*rm is faster than rm**3
        a = r/rmcub.reshape(np.append(np.shape(r[:,:,0]),1))    # This was surprisingly hard to get working
        a *= astcnst.G.value*M.reshape(1,np.size(M),1)             # So I do it one step at a time.
        a[np.isnan(a)] = 0      # Convert nans back to 0.
        acc = np.sum(a,axis=1)  # And sum all the accelerations.
        return acc
    
    def electrostatic(self):
        pass
    
    def lennard_jones(self):
        pass
    
    def spring(self):
        pass



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Mon May 27 15:53:45 2019

@author: hogbobson
"""

from setuptools import setup, find_packages

setup(name='hpsim',
      version='0.0.6',
      description='A modular, high performance particle simulator',
      url='http://github.com/Hogbobson/hpsim',
      author='Mads Kildholt',
      author_email='hogbobson@gmail.com',
      license='GNU General Public License v3',
      packages=find_packages(),
)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue May 28 19:46:43 2019

@author: hogbobson
"""

import numpy as np
from matplotlib import pyplot as plt


class visual:
    def __init__(self):
        pass
    
    def no_plot(self, ensemble):
        pass
    
    def standard_plot(self, ensemble):
        n = ensemble['number of objects']
        plt.figure(num = 0, figsize = (8,8))
        for i in range(n):
            plt.plot(ensemble['r data'][i,0,:], ensemble['r data'][i,1,:], '-', \
                     label = ensemble['label'][i], \
                     color = (abs(np.sin(i)), 0 + i/n, 1-i/n))
        plt.xlabel('x')
        plt.ylabel('y')
        xlim = np.max(ensemble['r data'])*1.1
        xlim = 5*1e11
        plt.axis((-xlim, xlim, -xlim, xlim))
        plt.legend()
        plt.show()
